@extends('themes.base.layout')
@section('title', $album->name)

@section('breadcrumb')
    <div class="breadcrumb">
        <div class="container">
            <ol class="breadcrumb">
                <li><a href="{{ route('home') }}">@lang('navigation.breadcrumb.home')</a></li>
                <li><a href="{{ route('admin') }}">@lang('navigation.breadcrumb.admin')</a></li>
                <li><a href="{{ route('albums.index') }}">@lang('navigation.breadcrumb.albums')</a></li>
                <li class="active">{{ $album->name }}</li>
            </ol>
        </div>
    </div>
@endsection

@section('content')
    <div class="container">
        <div class="row">
            <div class="col-xs-12">
                <a class="pull-right btn btn-default" href="{{ $album->url() }}" target="_blank"><i class="fa fa-fw fa-eye"></i> @lang('admin.open_album')</a>

                <h1 class="page-title">{{ $album->name }}</h1>
                <p>{{ $album->description }}</p>
                <hr/>

                <div>
                    <ul class="nav nav-tabs" role="tablist">
                        <li role="presentation" class="active"><a href="#photos-tab" aria-controls="photos-tab" role="tab" data-toggle="tab"><i class="fa fa-fw fa-photo"></i> @lang('admin.album_photos_tab')</a></li>
                        <li role="presentation"><a href="#upload-tab" aria-controls="upload-tab" role="tab" data-toggle="tab"><i class="fa fa-fw fa-upload"></i> @lang('admin.album_upload_tab')</a></li>
                        <li role="presentation"><a href="#settings-tab" aria-controls="settings-tab" role="tab" data-toggle="tab"><i class="fa fa-fw fa-cog"></i> @lang('admin.album_settings_tab')</a></li>
                    </ul>

                    <div class="tab-content">
                        {{-- Photos --}}
                        <div role="tabpanel" class="tab-pane active" id="photos-tab">
                            @if (count($photos) == 0)
                                <div class="text-center" style="margin-top: 30px;">
                                    <h4 class="text-danger"><b>@lang('admin.album_no_photos_p1')</b></h4>
                                    <p>@lang('admin.album_no_photos_p2')</p>
                                    <p style="margin-top: 30px;"><button id="upload-button" class="btn btn-lg btn-success">@lang('admin.album_no_photos_button')</button></p>
                                </div>
                            @else
                                {!! Form::open(['route' => ['photos.updateBulk', $album->id], 'method' => 'PUT']) !!}

                                @foreach ($photos as $photo)
                                    @include (Theme::viewName('partials.single_photo_admin'))
                                @endforeach

                                <div class="pull-left">
                                    <p>{!! Form::label('bulk-action', trans('forms.bulk_edit_photos_label'), ['class' => 'control-label']) !!}</p>
                                    {!! Form::select('bulk-action', $bulk_actions, null, ['placeholder' => trans('forms.bulk_edit_photos_placeholder'), 'id' => 'bulk-action-apply']) !!}
                                    <button type="submit" class="btn btn-sm btn-success" name="bulk-apply" value="clicked">@lang('forms.apply_action')</button>
                                </div>
                                <div class="pull-right">
                                    <button type="submit" class="btn btn-success">@lang('forms.save_action')</button>
                                </div>
                                <div class="clearfix"></div>

                                {!! Form::close() !!}

                                <div class="text-center">
                                    {{ $photos->links() }}
                                </div>
                            @endif
                        </div>

                        {{-- Upload --}}
                        <div role="tabpanel" class="tab-pane" id="upload-tab">
                            @if (!$is_upload_enabled)
                                <div class="row">
                                    <div class="col-xs-12">
                                        <p class="text-danger" style="font-weight: bold">@lang('admin.upload_disabled_heading')</p>
                                        <p>@lang('admin.upload_disabled_text')</p>
                                    </div>
                                </div>
                            @else
                                <h4>@lang('admin.upload_single_file_heading')</h4>
                                <p>@lang('admin.upload_single_file_text')</p>
                                <div class="alert alert-info">
                                    <p>@lang('admin.upload_single_file_text2', [
                                        'file_size' => sprintf('<b>%s%s</b>', round($file_upload_limit, 2), trans('global.units.megabytes')),
                                        'max_upload_size' => sprintf('<b>%s%s</b>', round($max_post_limit, 2), trans('global.units.megabytes'))
                                    ])</p>
                                </div>

                                <div class="row">
                                    <div class="col-sm-5" style="margin-bottom: 20px;">
                                        {!! Form::open(['route' => 'photos.store', 'method' => 'POST', 'files' => true, 'id' => 'single-upload-form']) !!}
                                        {!! Form::hidden('album_id', $album->id) !!}

                                        <div class="form-group">
                                            {!! Form::file('photo[]', ['class' => 'control-label', 'multiple' => 'multiple', 'id' => 'single-upload-files']) !!}
                                        </div>

                                        <div>
                                            <button type="submit" class="btn btn-success" data-bind="disable: (isUploadInProgress() || isBulkUploadInProgress()), text: isUploadInProgress() ? '@lang('admin.is_uploading')' : '@lang('forms.upload_action')'">@lang('forms.upload_action')</button>
                                        </div>
                                        {!! Form::close() !!}
                                    </div>

                                    <div class="col-sm-5">
                                        <div class="text-center" data-bind="visible: isUploadInProgress">
                                            <p><b>@lang('admin.is_uploading')</b></p>
                                            <div class="progress">
                                                <div class="progress-bar progress-bar-success" data-bind="style: { width: successfulPercentage() }">
                                                    <span class="sr-only"><span class="percentage-success" data-bind="text: successfulPercentage"></span></span>
                                                </div>
                                                <div class="progress-bar progress-bar-danger" data-bind="style: { width: failedPercentage() }">
                                                    <span class="sr-only"><span class="percentage-danger" data-bind="text: failedPercentage"></span></span>
                                                </div>
                                            </div>
                                            <p data-bind="text: currentStatus"></p>
                                        </div>

                                        <div data-bind="visible: statusMessages().length > 0">
                                            <p data-bind="visible: !isUploadInProgress()" class="text-danger" style="font-weight: bold">
                                                <span data-bind="text: imagesFailed"></span> @lang('admin.upload_file_number_failed')
                                            </p>
                                            <p data-bind="visible: imagesUploaded() > 0">
                                                @lang('admin.upload_file_failed_continue')<br /><br/>
                                                <a href="{{ route('albums.analyse', ['id' => $album->id]) }}" class="btn btn-primary">@lang('forms.continue_action')</a>
                                            </p>

                                            <ul data-bind="foreach: statusMessages">
                                                <li data-bind="css: message_class, text: message_text"></li>
                                            </ul>
                                        </div>
                                    </div>
                                </div>

                                <hr/>
                                <h4>@lang('admin.upload_bulk_heading')</h4>
                                <p>@lang('admin.upload_bulk_text')</p>
                                <div class="alert alert-info">
                                    <p>@lang('admin.upload_bulk_text2', [
                                        'max_upload_size' => sprintf('<b>%s%s</b>', round($max_post_limit_bulk, 2), trans('global.units.megabytes'))
                                    ])</p>
                                </div>

                                {!! Form::open(['route' => 'photos.storeBulk', 'method' => 'POST', 'files' => true, 'id' => 'bulk-upload-form']) !!}
                                {!! Form::hidden('album_id', $album->id) !!}

                                <div class="form-group">
                                    {!! Form::file('archive', ['class' => 'control-label']) !!}
                                </div>

                                <div>
                                    <button type="submit" class="btn btn-success" data-bind="disable: (isUploadInProgress() || isBulkUploadInProgress()), text: isBulkUploadInProgress() ? '@lang('admin.is_uploading')' : '@lang('forms.upload_action')'">@lang('forms.upload_action')</button>
                                </div>
                                {!! Form::close() !!}
                            @endif
                        </div>

                        {{-- Settings --}}
                        <div role="tabpanel" class="tab-pane" id="settings-tab">
                            <div class="btn-toolbar">
                                <a href="{{ route('albums.edit', ['id' => $album->id]) }}" class="btn btn-default">@lang('forms.edit_action')</a>
                                <a href="{{ route('albums.delete', ['id' => $album->id]) }}" class="btn btn-danger">@lang('forms.delete_action')</a>
                            </div>
                        </div>
                    </div>
                </div>
            </div>
        </div>
    </div>
@endsection

@push('scripts')
<script type="text/javascript">
    var language = [];
    language.image_failed = '{!! addslashes(trans('admin.upload_file_status_failed')) !!}';
    language.image_uploaded = '{!! addslashes(trans('admin.upload_file_status_success')) !!}';
    language.upload_status = '{!! addslashes(trans('admin.upload_file_status_progress')) !!}';

    var urls = [];
    urls.analyse = '{{ route('albums.analyse', ['id' => $album->id]) }}';

    var viewModel = new UploadPhotosViewModel('{{ $album->id }}', language, urls);

    function deletePhoto(photo_id, parent)
    {
        var url = '{{ route('photos.destroy', ['id' => 0]) }}';
        url = url.replace(/\/0$/, '/' + photo_id);

        $('.loading', parent).show();

        $.post(url, {'_method': 'DELETE'}, function(data)
        {
            window.location.reload();
        });
    }

    function flipPhoto(photo_id, horizontal, vertical, parent)
    {
        var url = '{{ route('photos.flip', ['id' => 0, 'horizontal' => -1, 'vertical' => -2]) }}';
        url = url.replace('/0/', '/' + photo_id + '/');

        if (horizontal)
        {
            url = url.replace(/\/-1\//, '/1/');
        }
        else
        {
            url = url.replace(/\/-1\//, '/0/');
        }

        if (vertical)
        {
            url = url.replace(/\/-2$/, '/1');
        }
        else
        {
            url = url.replace(/\/-2$/, '/0');
        }

        $('.loading', parent).show();
        $.post(url, function()
        {
            var image = $('img.photo-thumbnail', parent);
            var originalUrl = image.data('original-src');
            image.attr('src', originalUrl + "&_=" + new Date().getTime());

            $('.loading', parent).hide();
        });
    }

    function regenerateThumbnails(photo_id, parent)
    {
        var url = '{{ route('photos.regenerateThumbnails', ['id' => 0]) }}';
        url = url.replace(/\/0$/, '/' + photo_id);

        $('.loading', parent).show();
        $.post(url, function()
        {
            var image = $('img.photo-thumbnail', parent);
            var originalUrl = image.data('original-src');
            image.attr('src', originalUrl + "&_=" + new Date().getTime());

            $('.loading', parent).hide();
        });
    }

    function rotatePhoto(photo_id, angle, parent)
    {
        var url = '{{ route('photos.rotate', ['id' => 0, 'angle' => 1]) }}';
        url = url.replace('/0/', '/' + photo_id + '/');
        url = url.replace(/\/1$/, '/' + angle);

        $('.loading', parent).show();
        $.post(url, function()
        {
            var image = $('img.photo-thumbnail', parent);
            var originalUrl = image.data('original-src');
            image.attr('src', originalUrl + "&_=" + new Date().getTime());

            $('.loading', parent).hide();
        });
    }

    $(document).ready(function() {
        $('#upload-button').click(function() {
            $('.nav-tabs a[href="#upload-tab"]').tab('show');
        });

        {{-- Photo editing tasks - the buttons beneath the photos in partials/single_photo_admin --}}
        $('a.delete-photo').click(function() {
            var parent = $(this).parents('.photo');
            var photo_id = $(parent).data('photo-id');

            $(this).dropdown('toggle');

            bootbox.dialog({
                message: 'Are you sure you want to delete this photo? This cannot be undone!',
                title: 'Delete photo',
                buttons: {
                    cancel: {
                        label: "Cancel",
                        className: "btn-default"
                    },
                    confirm: {
                        label: "Delete",
                        className: "btn-danger",
                        callback: function() {
                            deletePhoto(photo_id, parent);
                        }
                    }
                }
            });

            return false;
        });
        $('a.flip-photo-both').click(function() {
            var parent = $(this).parents('.photo');
            var photo_id = $(parent).data('photo-id');

            flipPhoto(photo_id, true, true, parent);
            $(this).dropdown('toggle');
            return false;
        });
        $('a.flip-photo-horizontal').click(function() {
            var parent = $(this).parents('.photo');
            var photo_id = $(parent).data('photo-id');

            flipPhoto(photo_id, true, false, parent);
            $(this).dropdown('toggle');
            return false;
        });
        $('a.flip-photo-vertical').click(function() {
            var parent = $(this).parents('.photo');
            var photo_id = $(parent).data('photo-id');

            flipPhoto(photo_id, false, true, parent);
            $(this).dropdown('toggle');
            return false;
        });
        $('a.regenerate-thumbnails').click(function() {
            var parent = $(this).parents('.photo');
            var photo_id = $(parent).data('photo-id');

            regenerateThumbnails(photo_id, parent);
            $(this).dropdown('toggle');
            return false;
        });
        $('a.rotate-photo-left').click(function() {
            var parent = $(this).parents('.photo');
            var photo_id = $(parent).data('photo-id');

            rotatePhoto(photo_id, 90, parent);
            $(this).dropdown('toggle');
            return false;
        });
        $('a.rotate-photo-right').click(function() {
            var parent = $(this).parents('.photo');
            var photo_id = $(parent).data('photo-id');

            rotatePhoto(photo_id, 270, parent);
            $(this).dropdown('toggle');
            return false;
        });

        {{-- Photo uploads using AJAX --}}
        if (window.FormData)
        {
            $('#single-upload-form').submit(function(event) {
                var fileSelect = $('#single-upload-files', this);
                var uploadButton = $('button[type=submit]', this);

                // Get the selected files
                var notImageString = '{!! addslashes(trans('admin.upload_file_not_image_messages')) !!}';
                var files = fileSelect[0].files;

                // Reset statistics
                viewModel.startUpload(files.length);

                // Loop through each of the selected files and upload them individually
                for (var i = 0; i < files.length; i++)
                {
                    var file = files[i];

                    // We're only interested in image files
                    if (!file.type.match('image.*'))
                    {
                        alert(notImageString.replace(':file_name', file.name));
                        viewModel.onUploadFailed(null, file.name);
                        continue;
                    }

                    // Upload the file
                    viewModel.uploadFile($(this), file);
                }

                // Prevent standard form upload
                event.preventDefault();
                return false;
            });

            $('#bulk-upload-form').submit(function(event) {
                // Set the in progress flag - no need to unset it as this is a synchronous process so the browser
                // will reload the page in some way after completion
                viewModel.isBulkUploadInProgress(true);
                return true;
            });
        }

        ko.applyBindings(viewModel);
    })
</script>
@endpush